@font-face {
  font-family: Source Sans Pro;
  font-weight: 400;
  src: url(sourcesanspro-regular.otf);
}
@font-face {
  font-family: Source Sans Pro;
  font-weight: 700;
  src: url(sourcesanspro-bold.otf);
}

@page {
  margin: 2cm;

    @bottom-right{
        content: "Page " counter(page) " / " counter(pages);
        font-size: .8em;
    }
}

html {
  color: #14213d;
  font-family: Source Sans Pro;
  font-size: 11pt;
  line-height: 1.6;
}
body {
  margin: 0;
}
#logo_container{
width: 100%;
text-align: center;
position: fixed;
top: -1.255555cm;

}
img{
  width: 4cm;
}
h1 {
  color: #1ee494;
  font-size: 18pt;
  margin: 0;
}

h2{
  margin-bottom: 0;
  color: #1ee494;
  font-size: 13pt;
}


aside address {
  font-style: normal;
  white-space: pre-line;
	line-height: 1;
}
aside address#from {
  color: #a9a;
  margin-bottom: 5cm;
}
aside address#to {
	position: absolute;
	top: 5cm;
	left: 11cm;
}

dl{
margin-top: 0;
}
dt, dd {
  display: inline;
  margin: 0;
}
dt {
  color: #a9a;
}
dt::before {
  content: '';
  display: block;
}
dt::after {
  content: ' :';
}

table {
  border-collapse: collapse;
  width: 100%;
}
th {
  border-bottom: .2mm solid #a9a;
  color: #a9a;
  font-size: 10pt;
  font-weight: 400;
  padding-bottom: .25cm;
  text-transform: uppercase;
}
.trfooter td {
  padding-top: 0;
  font-weight: 700;
}
.trfooter td:first-of-type {
  text-align: right;
}
td:last-of-type {
  color: #1ee494;
  font-weight: 700;
  text-align: right;
}
th, td {
  text-align: center;
}
th:first-of-type, td:first-of-type {
  text-align: left;
}
th:last-of-type, td:last-of-type {
  text-align: right;
}
tr.description td{
  text-align: left;
  color: #a9a;
  font-size: 8pt;
  padding-bottom: 3mm;

}
footer{
  width: 100%;
  font-size: 9pt;
  text-align: center;
  position: fixed;
  bottom: -1.5cm;
  line-height: 1;
}

.conditions{
  color: black;
page-break-before: always;
margin-left: -1cm;
margin-right: -1cm;
}
.conditions div{
column-count: 4;
  font-size: 7.4pt;
  line-height: 1.1;
  font-weight: normal;
}
.conditions ul{
padding-left: 1em;
margin-top: 0.2em;
margin-bottom: 0.2em;
}
.conditions ol{
padding-left: 1em;
margin-top: 0.2em;
margin-bottom: 0.2em;
}
.conditions h3{
  margin-bottom: 0.5em;
  margin-top: 0.5em;
}
.conditions h4{
  margin-bottom: 0.2em;
  margin-top: 0.5em;
}
.conditions p{
  margin-bottom: 0.2em;
  margin-top: 0.2em;
}
.conditions h2{
margin-top:0;
margin-bottom:0;
}
