# Generated by Django 6.0.2 on 2026-02-24 14:54

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("hbdjinvoicing", "0005_invoice_customer_vat_id_alter_organisation_vat_id"),
    ]

    operations = [
        migrations.AddField(
            model_name="organisation",
            name="conditions",
            field=models.TextField(blank=True, default=""),
        ),
    ]
