# Generated by Django 5.1.6 on 2025-02-25 18:06

import django_countries.fields
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("hbdjinvoicing", "0002_remove_invoice_customer_delete_customer"),
    ]

    operations = [
        migrations.AlterField(
            model_name="invoice",
            name="country",
            field=django_countries.fields.CountryField(max_length=2),
        ),
        migrations.AlterField(
            model_name="organisation",
            name="country",
            field=django_countries.fields.CountryField(max_length=2),
        ),
    ]
