# Generated by Django 5.1.6 on 2025-08-22 09:38

import localflavor.generic.validators
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("hbdjinvoicing", "0004_alter_invoice_street_alter_organisation_street"),
    ]

    operations = [
        migrations.AddField(
            model_name="invoice",
            name="customer_vat_id",
            field=models.CharField(
                blank=True,
                default="",
                validators=[localflavor.generic.validators.VATINValidator],
            ),
        ),
        migrations.AlterField(
            model_name="organisation",
            name="vat_id",
            field=models.CharField(
                validators=[localflavor.generic.validators.VATINValidator]
            ),
        ),
    ]
