# Generated by Django 5.1.6 on 2026-03-20 17:23

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("hbdjinvoicing", "0006_organisation_conditions"),
    ]

    operations = [
        migrations.AddField(
            model_name="invoice",
            name="credit",
            field=models.ForeignKey(
                blank=True,
                default=None,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to="hbdjinvoicing.invoice",
            ),
        ),
    ]
